Read2 <- 
function(..., sep=";", dec=",") 
         
  Read(..., fun_call=match.call(), sep=";", dec=",")
